==> queen-beecon_1.0.5.tar.gz: queen-beecon-1.0.5/queen-beecon-advanced-tools-dialog.h <==
/*
 * This file is a part of Queen Beecon Widget
 * queen-beecon-advanced-tools-dialog: Utility for QBW Advanced Tools Dialog Box Management
 *
 * http://talk.maemo.org/showthread.php?t=45388
 *
 * Copyright (c) 2010 No!No!No!Yes! (Alessandro Peralma)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version. or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef QUEEN_BEECON_ADVANCED_TOOLS_DIALOG_H
#define QUEEN_BEECON_ADVANCED_TOOLS_DIALOG_H

guint checksum(gchar *buffer);
void on_command_picker_value_changed(HildonPickerButton * button, QueenBeecon *self);
void testDriveBt_clicked_cb(HildonButton * button, QueenBeecon *self);
void copyCommandBt_clicked_cb ( HildonButton * button, QueenBeecon *self );
void pasteCommandBt_clicked_cb ( HildonButton * button, QueenBeecon *self );
void updateCommandBt_clicked_cb ( HildonButton * button, QueenBeecon *self );
void importCommandBt_clicked_cb ( HildonButton * button, QueenBeecon *self );
void exportCommandBt_clicked_cb ( HildonButton * button, QueenBeecon *self );
void pasteFromClipboardADBExportImportBt_clicked_cb ( HildonButton * button, QueenBeecon *self );
void copyToClipboardADBExportImportBt_clicked_cb ( HildonButton * button, QueenBeecon *self );
void importInstanceBt_clicked_cb ( HildonButton *button, QueenBeecon *self );
void exportInstanceBt_clicked_cb ( HildonButton * button, QueenBeecon *self );
void importFileBufferBt_clicked_cb ( HildonButton * button, QueenBeecon *self );
void exportFileBufferBt_clicked_cb ( HildonButton * button, QueenBeecon *self );
gboolean queen_beecon_advanced_dialog ( QueenBeecon *self, gint cmdSel);

#endif /* QUEEN_BEECON_ADVANCED_TOOLS_DIALOG_H */

==> queen-beecon_1.3.3.tar.gz: queen-beecon-1.3.3/queen-beecon-advanced-tools-dialog.h <==
/*
 * This file is a part of Queen Beecon Widget
 * queen-beecon-advanced-tools-dialog: Utility for QBW Advanced Tools Dialog Box Management
 *
 * http://talk.maemo.org/showthread.php?t=45388
 *
 * Copyright (c) 2010 No!No!No!Yes! (Alessandro Peralma)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version. or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef QUEEN_BEECON_ADVANCED_TOOLS_DIALOG_H
#define QUEEN_BEECON_ADVANCED_TOOLS_DIALOG_H

guint checksum(gchar *buffer);
void on_command_picker_value_changed(HildonPickerButton * button, QueenBeecon *self);
void testDriveBt_clicked_cb(HildonButton * button, QueenBeecon *self);
void copyCommandBt_clicked_cb ( HildonButton * button, QueenBeecon *self );
void pasteCommandBt_clicked_cb ( HildonButton * button, QueenBeecon *self );
void updateCommandBt_clicked_cb ( HildonButton * button, QueenBeecon *self );
void importCommandBt_clicked_cb ( HildonButton * button, QueenBeecon *self );
void exportCommandBt_clicked_cb ( HildonButton * button, QueenBeecon *self );
void pasteFromClipboardADBExportImportBt_clicked_cb ( HildonButton * button, QueenBeecon *self );
void copyToClipboardADBExportImportBt_clicked_cb ( HildonButton * button, QueenBeecon *self );
void importInstanceBt_clicked_cb ( HildonButton *button, QueenBeecon *self );
void exportInstanceBt_clicked_cb ( HildonButton * button, QueenBeecon *self );
void importFileBufferBt_clicked_cb ( HildonButton * button, QueenBeecon *self );
void exportFileBufferBt_clicked_cb ( HildonButton * button, QueenBeecon *self );
gboolean queen_beecon_advanced_dialog ( QueenBeecon *self, gint *cmdSel);

#endif /* QUEEN_BEECON_ADVANCED_TOOLS_DIALOG_H */
